function [ kt ] = Stress_Step_Bending( Big_Dia, Small_Dia, Fillet )
%
%  This routine computes the stress concentration factor for an bending load
%  on a circular shaft with a diameter change.  Values are taken from
%  page 1028, Figure C-2 in Norton
%
%      Big_Dia = the larger diameter
%      Small_Dia = the smaller diameter
%      Fillet = the radius of the fillet at the step

Dt = [6.0 3.0 2.0 1.5 1.2 1.1 1.07 1.05 1.03 1.02 1.01]';
At = [.87868 .89334 .90879 .93836 .97098 .95120 .97527 .98137 .98061 .96048 .91938]';
bt = [-.33243 -.30860 -.28598 -.25759 -.21796 -.23757 -.20958 -.19653 -.18381 -.17711 -.17032]';

%  Compute the diameter ratio and then interpolate A and b from the tables

D = Big_Dia / Small_Dia;
A = interp1 (Dt, At, D);
b = interp1 (Dt, bt, D);

%  Compute the stress concentration factor

kt = A * (Fillet / Small_Dia) ^ b;

end

